==> dna-0.4.0.tar.gz: test/win_test.dart <==
//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

@TestOn("windows")

import 'dart:io';
import 'package:test/test.dart';
import '../lib/dna.dart';


void main() {

  group('base tests', () {
    int library;

    setUp(() {
      library =  loadLibrary('kernel32.dll');
    });

    tearDown(() {
      freeLibrary(library);
    });

    test('library', () {
      expect(library, isNonZero);
    });

    test('empty vm', () {
      var vm = createCallVM(256);
      expect(vm, isNonZero);
      freeCallVM(vm);
    });

    test('getpid', () {

      var method = findSymbol(library, 'GetCurrentProcess');
      expect(method, isNonZero);
      var vm = createCallVM(256);
      var processPointer = callFunction(vm, method, new String.fromCharCodes([C_INT]));
      freeCallVM(vm);

      method = findSymbol(library, 'GetProcessId');
      expect(method, isNonZero);
      vm = createCallVM(256);
      pushParameters(vm, new String.fromCharCodes([C_INT]), [processPointer]);
      var processId = callFunction(vm, method, new String.fromCharCodes([C_INT]));
      freeCallVM(vm);

      expect(processId, isNonZero);
      expect(processId, equals(pid));
    });


  });
}

==> dna-0.5.0.tar.gz: test/win_test.dart <==
//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

@TestOn("windows")

import 'dart:io';
import 'package:test/test.dart';
import '../lib/dna.dart';


void main() {

  group('base tests', () {
    int library;

    setUp(() {
      library =  loadLibrary('kernel32.dll');
    });

    tearDown(() {
      freeLibrary(library);
    });

    test('library', () {
      expect(library, isNonZero);
    });

    test('empty vm', () {
      var vm = createCallVM(256);
      expect(vm, isNonZero);
      freeCallVM(vm);
    });

    test('getpid', () {

      var method = findSymbol(library, 'GetCurrentProcess');
      expect(method, isNonZero);
      var vm = createCallVM(256);
      var processPointer = callFunction(vm, method, C_INT);
      freeCallVM(vm);

      method = findSymbol(library, 'GetProcessId');
      expect(method, isNonZero);
      vm = createCallVM(256);
      pushParameters(vm, [C_INT], [processPointer]);
      var processId = callFunction(vm, method, C_INT);
      freeCallVM(vm);

      expect(processId, isNonZero);
      expect(processId, equals(pid));
    });


  });
}
